@@ -23,7 +23,7 @@ import yaml
 from base64 import b64encode
 from re import match
 
-from fixtures import muchdata, reset_textstore, teststore
+from fixtures import muchdata, reset_textstore, _teststore
 
 from tiddlyweb.model.user import User
 
@@ -37,8 +37,8 @@ def setup_module(module):
     httplib2_intercept.install()
     wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
 
-    module.store = teststore()
     reset_textstore()
+    module.store = _teststore()
     muchdata(module.store)
 
     # we're going to need a user for testing auth stuff
